@@ -1,17 +1,14 @@
 package App::PYX2XML;
 
-# Pragmas.
 use strict;
 use warnings;
 
-# Modules.
 use Getopt::Std;
 use PYX::SGML::Tags;
 use Tags::Output::Indent;
 use Tags::Output::Raw;
 
-# Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -20,26 +17,6 @@ sub new {
 	# Create object.
 	my $self = bless {}, $class;
 
-	# Process arguments.
-	$self->{'_opts'} = {
-		'e' => 'utf-8',
-		'h' => 0,
-		'i' => 0,
-	};
-	if (! getopts('ehi', $self->{'_opts'}) || $self->{'_opts'}->{'h'}
-		|| @ARGV < 1) {
-
-		print STDERR "Usage: $0 [-e in_enc] [-h] [-i] [--version] [filename] [-]\n";
-		print STDERR "\t-e in_enc\tInput encoding (default value is utf-8)\n";
-		print STDERR "\t-h\t\tPrint help.\n";
-		print STDERR "\t-i\t\tIndent output.\n";
-		print STDERR "\t--version\tPrint version.\n";
-		print STDERR "\t[filename]\tProcess on filename\n";
-		print STDERR "\t[-]\t\tProcess on stdin\n";
-		exit 1;
-	}
-	$self->{'_filename_or_stdin'} = $ARGV[0];
-
 	# Object.
 	return $self;
 }
@@ -48,11 +25,33 @@ sub new {
 sub run {
 	my $self = shift;
 
+	# Process arguments.
+	$self->{'_opts'} = {
+		'e' => 'utf-8',
+		'h' => 0,
+		'i' => 0,
+	};
+	if (! getopts('e:hi', $self->{'_opts'}) || $self->{'_opts'}->{'h'}
+		|| @ARGV < 1) {
+
+		print STDERR "Usage: $0 [-e in_enc] [-h] [-i] [--version] ".
+			"[filename] [-]\n";
+		print STDERR "\t-e in_enc\tInput encoding (default value ".
+			"is utf-8)\n";
+		print STDERR "\t-h\t\tPrint help.\n";
+		print STDERR "\t-i\t\tIndent output.\n";
+		print STDERR "\t--version\tPrint version.\n";
+		print STDERR "\t[filename]\tProcess on filename\n";
+		print STDERR "\t[-]\t\tProcess on stdin\n";
+		return 1;
+	}
+	$self->{'_filename_or_stdin'} = $ARGV[0];
+
 	# Tags object.
 	my $tags;
 	my %params = (
-		'xml' => 1,
 		'output_handler' => \*STDOUT,
+		'xml' => 1,
 	);
 	if ($self->{'_opts'}->{'i'}) {
 		$tags = Tags::Output::Indent->new(%params);
@@ -94,6 +93,7 @@ App::PYX2XML - Perl class for pyx2xml application.
 =head1 SYNOPSIS
 
  use App::PYX2XML;
+
  my $obj = App::PYX2XML->new;
  $obj->run;
 
@@ -119,11 +119,9 @@ App::PYX2XML - Perl class for pyx2xml application.
 
 =head1 EXAMPLE
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use App::PYX2XML;
 
  # Run.
@@ -147,21 +145,22 @@ L<Tags::Output::Raw>.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/App-PYX2XML>.
+L<https://github.com/michal-josef-spacek/App-PYX2XML>.
 
 =head1 AUTHOR
 
-Michal Špaček L<mailto:skim@cpan.org>
+Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2015-2016 Michal Špaček
- BSD 2-Clause License
+© 2015-2020 Michal Josef Špaček
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
